# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`openscap`](#openscap): This class installs SCAP content and the associated tools. It is mostly based on the scap-security-guide open source project with several cus
* [`openscap::schedule`](#openscap--schedule): This class allows you to set a schedule for openscap to run a check on your system via cron.

### Data types

* [`Openscap::Profile`](#Openscap--Profile): Valid OpenSCAP profile names

## Classes

### <a name="openscap"></a>`openscap`

This class installs SCAP content and the associated tools.
It is mostly based on the scap-security-guide open source project
with several customizations for SIMP.

#### Parameters

The following parameters are available in the `openscap` class:

* [`enable_schedule`](#-openscap--enable_schedule)
* [`scap_ensure`](#-openscap--scap_ensure)
* [`ssg_ensure`](#-openscap--ssg_ensure)

##### <a name="-openscap--enable_schedule"></a>`enable_schedule`

Data type: `Boolean`

Run an OpenSCAP scan on a schedule, using `openscap::schedule`

Default value: `false`

##### <a name="-openscap--scap_ensure"></a>`scap_ensure`

Data type: `String`

Package ensure value for the `openscap-utils` package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-openscap--ssg_ensure"></a>`ssg_ensure`

Data type: `String`

Package ensure value for the `scap-security-guide` package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="openscap--schedule"></a>`openscap::schedule`

This class allows you to set a schedule for openscap to run a check
on your system via cron.

#### Parameters

The following parameters are available in the `openscap::schedule` class:

* [`scap_profile`](#-openscap--schedule--scap_profile)
* [`oscap_path`](#-openscap--schedule--oscap_path)
* [`ssg_base_dir`](#-openscap--schedule--ssg_base_dir)
* [`ssg_data_stream`](#-openscap--schedule--ssg_data_stream)
* [`fetch_remote_resources`](#-openscap--schedule--fetch_remote_resources)
* [`scap_tailoring_file`](#-openscap--schedule--scap_tailoring_file)
* [`logdir`](#-openscap--schedule--logdir)
* [`logrotate`](#-openscap--schedule--logrotate)
* [`minute`](#-openscap--schedule--minute)
* [`hour`](#-openscap--schedule--hour)
* [`monthday`](#-openscap--schedule--monthday)
* [`month`](#-openscap--schedule--month)
* [`weekday`](#-openscap--schedule--weekday)
* [`force`](#-openscap--schedule--force)

##### <a name="-openscap--schedule--scap_profile"></a>`scap_profile`

Data type: `Openscap::Profile`

The name of the profile with the content.

* Valid profiles change based on the target system. See the results of the
`oscap` fact for valid targets.

##### <a name="-openscap--schedule--oscap_path"></a>`oscap_path`

Data type: `Stdlib::Absolutepath`

The path to the `oscap` executable

* This is set to a sane default for most systems but will pick the value
   out of the `oscap` fact if it has been installed and is in the path.

Default value: `pick(fact('oscap.path'), '/bin/oscap')`

##### <a name="-openscap--schedule--ssg_base_dir"></a>`ssg_base_dir`

Data type: `Stdlib::Absolutepath`

The starting directory for all SSG content. Change this if you want to
install your own SSG profiles.

Default value: `'/usr/share/xml/scap/ssg/content'`

##### <a name="-openscap--schedule--ssg_data_stream"></a>`ssg_data_stream`

Data type: `Pattern[/^.+\.xml$/]`

Type: XML file under $ssg_base_dir
The data stream XML file to use for your system scan. This must be a file
under $ssg_base_dir.

##### <a name="-openscap--schedule--fetch_remote_resources"></a>`fetch_remote_resources`

Data type: `Boolean`

If true, download remote content referenced by XCCDF.

Default value: `false`

##### <a name="-openscap--schedule--scap_tailoring_file"></a>`scap_tailoring_file`

Data type: `Optional[Stdlib::Absolutepath]`

Use  given  file  for XCCDF tailoring.

Default value: `undef`

##### <a name="-openscap--schedule--logdir"></a>`logdir`

Data type: `Stdlib::Absolutepath`

Specifies output location.  Default is /var/log/openscap

Default value: `'/var/log/openscap'`

##### <a name="-openscap--schedule--logrotate"></a>`logrotate`

Data type: `Boolean`

If true, use logrotate to rotate the output logs.

Default value: `simplib::lookup('simp_options::logrotate', { 'default_value' => false})`

##### <a name="-openscap--schedule--minute"></a>`minute`

Data type: `Simplib::Cron::Minute`



Default value: `30`

##### <a name="-openscap--schedule--hour"></a>`hour`

Data type: `Simplib::Cron::Hour`



Default value: `1`

##### <a name="-openscap--schedule--monthday"></a>`monthday`

Data type: `Simplib::Cron::MonthDay`



Default value: `'*'`

##### <a name="-openscap--schedule--month"></a>`month`

Data type: `Simplib::Cron::Month`



Default value: `'*'`

##### <a name="-openscap--schedule--weekday"></a>`weekday`

Data type: `Simplib::Cron::Weekday`



Default value: `1`

##### <a name="-openscap--schedule--force"></a>`force`

Data type: `Boolean`

If set, ignore the fact that `oscap` does not appear to be installed on the
target system and add the schedule anyway

* This should be used if you've installed `oscap` into a non-standard
  location that cannot be found by the fact in the default path

Default value: `false`

## Data types

### <a name="Openscap--Profile"></a>`Openscap::Profile`

Valid OpenSCAP profile names

Alias of `Pattern[/xccdf_[^_]+_profile_.+/]`

